@@ -1,33 +1,18 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #ifndef DEVICELINK_H
 #define DEVICELINK_H
 
 #include <QObject>
-#include <QtCrypto>
 
-#include "core/networkpackage.h"
+#include "networkpacket.h"
 
 class PairingHandler;
-class NetworkPackage;
+class NetworkPacket;
 class LinkProvider;
 class Device;
 
@@ -47,7 +32,7 @@ public:
     const QString& deviceId() const { return m_deviceId; }
     LinkProvider* provider() { return m_linkProvider; }
 
-    virtual bool sendPackage(NetworkPackage& np) = 0;
+    virtual bool sendPacket(NetworkPacket& np) = 0;
 
     //user actions
     virtual void userRequestsPair() = 0;
@@ -64,10 +49,7 @@ Q_SIGNALS:
     void pairingRequestExpired(PairingHandler* handler);
     void pairStatusChanged(DeviceLink::PairStatus status);
     void pairingError(const QString& error);
-    void receivedPackage(const NetworkPackage& np);
-
-protected:
-    QCA::PrivateKey m_privateKey;
+    void receivedPacket(const NetworkPacket& np);
 
 private:
     const QString m_deviceId;
