@@ -1,21 +1,7 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "landevicelink.h"
@@ -114,7 +100,7 @@ bool LanDeviceLink::sendPacket(NetworkPacket& np)
 
 void LanDeviceLink::dataReceived()
 {
-    if (m_socketLineReader->bytesAvailable() == 0) return;
+    if (!m_socketLineReader->hasPacketsAvailable()) return;
 
     const QByteArray serializedPacket = m_socketLineReader->readLine();
     NetworkPacket packet((QString()));
@@ -148,7 +134,7 @@ void LanDeviceLink::dataReceived()
 
     Q_EMIT receivedPacket(packet);
 
-    if (m_socketLineReader->bytesAvailable() > 0) {
+    if (m_socketLineReader->hasPacketsAvailable()) {
         QMetaObject::invokeMethod(this, "dataReceived", Qt::QueuedConnection);
     }
 
