@@ -1,21 +1,7 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "device.h"
@@ -276,7 +262,7 @@ void Device::addLink(const NetworkPacket& identityPacket, DeviceLink* link)
     //qCDebug(KDECONNECT_CORE) << "Adding link to" << id() << "via" << link->provider();
 
     setName(identityPacket.get<QString>(QStringLiteral("deviceName")));
-    d->m_deviceType = str2type(identityPacket.get<QString>(QStringLiteral("deviceType")));
+    setType(identityPacket.get<QString>(QStringLiteral("deviceType")));
 
     if (d->m_deviceLinks.contains(link)) {
         return;
@@ -506,10 +492,21 @@ void Device::setName(const QString& name)
 {
     if (d->m_deviceName != name) {
         d->m_deviceName = name;
+        KdeConnectConfig::instance().setDeviceProperty(d->m_deviceId, QStringLiteral("name"), name);
         Q_EMIT nameChanged(name);
     }
 }
 
+void Device::setType(const QString& strtype)
+{
+    auto type = str2type(strtype);
+    if (d->m_deviceType != type) {
+        d->m_deviceType = type;
+        KdeConnectConfig::instance().setDeviceProperty(d->m_deviceId, QStringLiteral("type"), strtype);
+        Q_EMIT typeChanged(strtype);
+    }
+}
+
 KdeConnectPlugin* Device::plugin(const QString& pluginName) const
 {
     return d->m_plugins[pluginName];
