@@ -1,21 +1,7 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #ifndef DBUSINTERFACES_H
@@ -25,7 +11,7 @@
 
 #include "daemoninterface.h"
 #include "deviceinterface.h"
-#include "devicebatteryinterface.h"
+#include "batteryinterface.h"
 #include "devicesftpinterface.h"
 #include "devicefindmyphoneinterface.h"
 #include "devicenotificationsinterface.h"
@@ -49,6 +35,8 @@ class KDECONNECTINTERFACES_EXPORT DaemonDbusInterface
     : public OrgKdeKdeconnectDaemonInterface
 {
     Q_OBJECT
+    Q_PROPERTY(QStringList customDevices
+               READ customDevices WRITE setCustomDevices NOTIFY customDevicesChangedProxy)
 public:
     explicit DaemonDbusInterface(QObject* parent = nullptr);
     ~DaemonDbusInterface() override;
@@ -58,6 +46,7 @@ public:
 Q_SIGNALS:
     void deviceAdded(const QString& id);
     void pairingRequestsChangedProxy();
+    void customDevicesChangedProxy();
 };
 
 class KDECONNECTINTERFACES_EXPORT DeviceDbusInterface
@@ -88,13 +77,18 @@ private:
     const QString m_id;
 };
 
-class KDECONNECTINTERFACES_EXPORT DeviceBatteryDbusInterface
+class KDECONNECTINTERFACES_EXPORT BatteryDbusInterface
     : public OrgKdeKdeconnectDeviceBatteryInterface
 {
     Q_OBJECT
+    Q_PROPERTY(int charge READ charge NOTIFY refreshedProxy)
+    Q_PROPERTY(bool isCharging READ isCharging NOTIFY refreshedProxy)
 public:
-    explicit DeviceBatteryDbusInterface(const QString& deviceId, QObject* parent = nullptr);
-    ~DeviceBatteryDbusInterface() override;
+    explicit BatteryDbusInterface(const QString& deviceId, QObject* parent = nullptr);
+    ~BatteryDbusInterface() override;
+
+Q_SIGNALS:
+    void refreshedProxy();
 };
 
 class KDECONNECTINTERFACES_EXPORT DeviceNotificationsDbusInterface
