@@ -1,40 +1,16 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "kcm.h"
 
-#include <QLabel>
-#include <QMenu>
-#include <QMenuBar>
-#include <QAction>
-#include <QStackedLayout>
-#include <QListView>
-#include <QDBusConnection>
-#include <QDBusInterface>
-
-#include <KServiceTypeTrader>
 #include <KPluginInfo>
 #include <KPluginMetaData>
-#include <KPluginFactory>
 #include <KAboutData>
 #include <KLocalizedString>
+#include <kcmutils_version.h>
 
 #include "ui_kcm.h"
 #include "interfaces/dbusinterfaces.h"
@@ -46,14 +22,14 @@ K_PLUGIN_FACTORY(KdeConnectKcmFactory, registerPlugin<KdeConnectKcm>();)
 
 static QString createId() { return QStringLiteral("kcm")+QString::number(QCoreApplication::applicationPid()); }
 
-KdeConnectKcm::KdeConnectKcm(QWidget *parent, const QVariantList&)
-    : KCModule(KAboutData::pluginData(QStringLiteral("kdeconnect-kcm")), parent)
+KdeConnectKcm::KdeConnectKcm(QWidget* parent, const QVariantList& args)
+    : KCModule(parent)
     , kcmUi(new Ui::KdeConnectKcmUi())
     , daemon(new DaemonDbusInterface(this))
     , devicesModel(new DevicesModel(this))
     , currentDevice(nullptr)
 {
-    KAboutData *about = new KAboutData(QStringLiteral("kdeconnect-kcm"),
+    KAboutData* about = new KAboutData(QStringLiteral("kdeconnect-kcm"),
                                        i18n("KDE Connect Settings"),
                                        QStringLiteral(KDECONNECT_VERSION_STRING),
                                        i18n("KDE Connect Settings module"),
@@ -67,8 +43,6 @@ KdeConnectKcm::KdeConnectKcm(QWidget *parent, const QVariantList&)
 
     kcmUi->setupUi(this);
 
-    kcmUi->deviceList->setIconSize(QSize(32,32));
-
     sortProxyModel = new DevicesSortProxyModel(devicesModel);
 
     kcmUi->deviceList->setModel(sortProxyModel);
@@ -79,10 +53,12 @@ KdeConnectKcm::KdeConnectKcm(QWidget *parent, const QVariantList&)
 
     //Workaround: If we set this directly (or if we set it in the .ui file), the layout breaks
     kcmUi->noDeviceLinks->setWordWrap(false);
-    QTimer::singleShot(0, [this] { kcmUi->noDeviceLinks->setWordWrap(true); });
+    QTimer::singleShot(0, this, [this] { kcmUi->noDeviceLinks->setWordWrap(true); });
 
-    kcmUi->rename_label->setText(daemon->announcedName());
-    kcmUi->rename_edit->setText(daemon->announcedName());
+    setWhenAvailable(daemon->announcedName(), [this](const QString& announcedName) {
+        kcmUi->rename_label->setText(announcedName);
+        kcmUi->rename_edit->setText(announcedName);
+    }, this);
     connect(daemon, SIGNAL(announcedNameChanged(QString)),
             kcmUi->rename_edit, SLOT(setText(QString)));
     connect(daemon, SIGNAL(announcedNameChanged(QString)),
@@ -95,6 +71,10 @@ KdeConnectKcm::KdeConnectKcm(QWidget *parent, const QVariantList&)
             this, &KdeConnectKcm::resetSelection);
     connect(kcmUi->deviceList->selectionModel(), &QItemSelectionModel::currentChanged,
             this, &KdeConnectKcm::deviceSelected);
+    connect(kcmUi->accept_button, &QAbstractButton::clicked,
+            this, &KdeConnectKcm::acceptPairing);
+    connect(kcmUi->reject_button, &QAbstractButton::clicked,
+            this, &KdeConnectKcm::rejectPairing);
     connect(kcmUi->pair_button, &QAbstractButton::clicked,
             this, &KdeConnectKcm::requestPair);
     connect(kcmUi->unpair_button, &QAbstractButton::clicked,
@@ -111,6 +91,29 @@ KdeConnectKcm::KdeConnectKcm(QWidget *parent, const QVariantList&)
             this, &KdeConnectKcm::renameShow);
 
     daemon->acquireDiscoveryMode(createId());
+
+    #if KCMUTILS_VERSION >= QT_VERSION_CHECK(5, 45, 0)
+
+    if (!args.isEmpty() && args.first().type() == QVariant::String) {
+        const QString input = args.first().toString();
+        const auto colonIdx = input.indexOf(QLatin1Char(':'));
+        const QString deviceId = input.left(colonIdx);
+        const QString pluginCM = colonIdx < 0 ? QString() : input.mid(colonIdx+1);
+
+        connect(devicesModel, &DevicesModel::rowsInserted, this, [this, deviceId, pluginCM]() {
+            auto row = devicesModel->rowForDevice(deviceId);
+            if (row >= 0) {
+                const QModelIndex idx = sortProxyModel->mapFromSource(devicesModel->index(row));
+                kcmUi->deviceList->selectionModel()->setCurrentIndex(idx, QItemSelectionModel::ClearAndSelect);
+            }
+            if (!pluginCM.isEmpty()) {
+                kcmUi->pluginSelector->showConfiguration(pluginCM);
+            }
+            disconnect(devicesModel, &DevicesModel::rowsInserted, this, nullptr);
+        });
+    }
+
+    #endif
 }
 
 void KdeConnectKcm::renameShow()
@@ -184,21 +187,23 @@ void KdeConnectKcm::deviceSelected(const QModelIndex& current)
     }
 
     kcmUi->messages->setVisible(false);
-    kcmUi->progressBar->setVisible(false);
-    if (currentDevice->isTrusted()) {
-        kcmUi->unpair_button->setVisible(true);
-        kcmUi->pair_button->setVisible(false);
-        kcmUi->ping_button->setVisible(true);
-    } else {
-        kcmUi->unpair_button->setVisible(false);
-        kcmUi->pair_button->setVisible(true);
-        kcmUi->ping_button->setVisible(false);
-    }
     resetDeviceView();
 
     connect(currentDevice, SIGNAL(pluginsChanged()), this, SLOT(resetCurrentDevice()));
     connect(currentDevice, SIGNAL(trustedChanged(bool)), this, SLOT(trustedChanged(bool)));
     connect(currentDevice, SIGNAL(pairingError(QString)), this, SLOT(pairingFailed(QString)));
+    connect(currentDevice, &DeviceDbusInterface::hasPairingRequestsChangedProxy, this, &KdeConnectKcm::currentDevicePairingChanged);
+}
+
+void KdeConnectKcm::currentDevicePairingChanged(bool pairing)
+{
+    if (pairing) {
+        setCurrentDeviceTrusted(RequestedByPeer);
+    } else {
+        setWhenAvailable(currentDevice->isTrusted(), [this](bool trusted) {
+            setCurrentDeviceTrusted(trusted ? Trusted : NotTrusted);
+        }, this);
+    }
 }
 
 void KdeConnectKcm::resetCurrentDevice()
@@ -220,7 +225,14 @@ void KdeConnectKcm::resetDeviceView()
     kcmUi->pluginSelector->setConfigurationArguments(QStringList(currentDevice->id()));
 
     kcmUi->name_label->setText(currentDevice->name());
-    kcmUi->status_label->setText(currentDevice->isTrusted()? i18n("(trusted)") : i18n("(not trusted)"));
+    setWhenAvailable(currentDevice->isTrusted(), [this](bool trusted) {
+        if (trusted)
+            setCurrentDeviceTrusted(Trusted);
+        else
+            setWhenAvailable(currentDevice->hasPairingRequests(), [this](bool haspr) {
+                setCurrentDeviceTrusted(haspr ? RequestedByPeer : NotTrusted);
+            }, this);
+    }, this);
 
     const QList<KPluginInfo> pluginInfo = KPluginInfo::fromMetaData(KPluginLoader::findPlugins(QStringLiteral("kdeconnect/")));
     QList<KPluginInfo> availablePluginInfo;
@@ -246,8 +258,7 @@ void KdeConnectKcm::requestPair()
 
     kcmUi->messages->hide();
 
-    kcmUi->pair_button->setVisible(false);
-    kcmUi->progressBar->setVisible(true);
+    setCurrentDeviceTrusted(Requested);
 
     currentDevice->requestPair();
 
@@ -259,29 +270,67 @@ void KdeConnectKcm::unpair()
         return;
     }
 
+    setCurrentDeviceTrusted(NotTrusted);
     currentDevice->unpair();
 }
 
+void KdeConnectKcm::acceptPairing()
+{
+    if (!currentDevice) {
+        return;
+    }
+
+    currentDevice->acceptPairing();
+}
+
+void KdeConnectKcm::rejectPairing()
+{
+    if (!currentDevice) {
+        return;
+    }
+
+    currentDevice->rejectPairing();
+}
+
 void KdeConnectKcm::pairingFailed(const QString& error)
 {
     if (sender() != currentDevice) return;
 
-    trustedChanged(false);
+    setCurrentDeviceTrusted(NotTrusted);
 
     kcmUi->messages->setText(i18n("Error trying to pair: %1",error));
     kcmUi->messages->animatedShow();
 }
 
-void KdeConnectKcm::trustedChanged(bool paired)
+void KdeConnectKcm::trustedChanged(bool trusted)
 {
     DeviceDbusInterface* senderDevice = (DeviceDbusInterface*) sender();
-    if (senderDevice != currentDevice) return;
+    if (senderDevice == currentDevice)
+        setCurrentDeviceTrusted(trusted ? Trusted : NotTrusted);
+}
 
-    kcmUi->pair_button->setVisible(!paired);
-    kcmUi->unpair_button->setVisible(paired);
-    kcmUi->progressBar->setVisible(false);
-    kcmUi->ping_button->setVisible(paired);
-    kcmUi->status_label->setText(paired ? i18n("(paired)") : i18n("(unpaired)"));
+void KdeConnectKcm::setCurrentDeviceTrusted(KdeConnectKcm::TrustStatus trusted)
+{
+    kcmUi->accept_button->setVisible(trusted == RequestedByPeer);
+    kcmUi->reject_button->setVisible(trusted == RequestedByPeer);
+    kcmUi->pair_button->setVisible(trusted == NotTrusted);
+    kcmUi->unpair_button->setVisible(trusted == Trusted);
+    kcmUi->progressBar->setVisible(trusted == Requested);
+    kcmUi->ping_button->setVisible(trusted == Trusted);
+    switch (trusted) {
+        case Trusted:
+            kcmUi->status_label->setText(i18n("(paired)"));
+            break;
+        case NotTrusted:
+            kcmUi->status_label->setText(i18n("(not paired)"));
+            break;
+        case RequestedByPeer:
+            kcmUi->status_label->setText(i18n("(incoming pair request)"));
+            break;
+        case Requested:
+            kcmUi->status_label->setText(i18n("(pairing requested)"));
+            break;
+    }
 }
 
 void KdeConnectKcm::pluginsConfigChanged()
