@@ -1,22 +1,8 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
- * Copyright 2018 Simon Redman <simon@ergotech.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2018 Simon Redman <simon@ergotech.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "telephonyplugin.h"
@@ -65,7 +51,7 @@ void TelephonyPlugin::createNotification(const NetworkPacket& np)
     qCDebug(KDECONNECT_PLUGIN_TELEPHONY) << "Creating notification with type:" << type;
 
     if (!m_currentCallNotification) {
-        m_currentCallNotification = new KNotification(type, KNotification::Persistent, this);
+        m_currentCallNotification = new KNotification(type, KNotification::Persistent);
     }
 
     if (!phoneThumbnail.isEmpty()) {
